restish.page — Restish v0.7.1 documentation

### Navigation

- index
- modules |
- Restish v0.7.1 documentation »

Overview

# restish.page

Page resource.

class `restish.page.` `Element`

  Bases: `restish.page.ElementMixin`, `object`

  Define a base Element type that is just an element

class `restish.page.` `ElementMixin`

  Bases: `object`

  Mixin to allow the use of element lookups on the resource

  `element`(request, name)

    Locate an element by name.

    The element is cached for the duration of the request to ensure that the same object is returned if the element is located again later.

exception `restish.page.` `ElementNotFound`
  Bases: `exceptions.Exception`

class `restish.page.` `Page`

  Bases: `restish.page.ElementMixin`, `restish.resource.Resource`

  Define a base Page type that includes elements

`restish.page.` `element`(name)
  Decorator to mark a method as an element factory.

### Navigation

- index
- modules |
- Restish v0.7.1 documentation »